"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class BadRequest extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
    }
    setResponse(obj) {
        this.response = obj;
        return this;
    }
    parseError(obj) {
        this.errInfo = obj.ErrInfo.split('|');
        this.errors = this.errInfo.map((code) => errorDefinition[code]);
        return this;
    }
    toString() {
        return `${this.name}: ${this.message}`;
    }
}
exports.BadRequest = BadRequest;
const errorDefinition = {
    'E00000000': `Please cancel the convenience store transaction error / settlement, and notify you that you can not make a transaction.`,
    'E01010001': `Shop ID is not set`,
    'E01010008': `Wrong ShopID format (Please make sure that ShopID should have 13 digits of alphanumeric characters only)`,
    'E01010010': `ShopID does not match`,
    'E01020001': `The shop password is not specified`,
    'E01020008': `Wrong ShopPass format (Please make sure that ShopPass should have 10 alphanumeric characters only)`,
    'E01030002': `Neither the specified ShopID nor ShopPass does not exist.`,
    'E01030061': `Forced Refund is not available`,
    'E01040001': `The order ID is not specified`,
    'E01040003': `The order ID exceeds the maximum character number`,
    'E01040010': `An order ID already exists`,
    'E01040013': `Wrong OrderID format (Please make sure that OrderID should only have alphanumeric characters and "-".)`,
    'E01050001': `"JobCd" is not specified.`,
    'E01050002': `The specified "JobCd" does not exist.`,
    'E01050004': `The specified "JobCd" is not available.`,
    'E01060001': `The amount of money is not specified`,
    'E01060005': `The amount of money exceeds the maximum digit number`,
    'E01060006': `The amount of money contains characters other than numbers`,
    'E01060010': `The Order ID was already used. It is possible that you have specified the Order ID again with the different payment amount`,
    'E01070005': `Tax shipping exceeds the maximum digit number`,
    'E01070006': `Tax shipping includes characters other than numbers`,
    'E01080007': `Wrong value is set for "TdFlag". Please set 0 or 1 for this parameter.`,
    'E01080010': `It does not match with the administration screen`,
    'E01080101': `Wrong value is set for "TdFlag". Please set 1 for this parameter.`,
    'E01090001': `Transaction ID is not specified`,
    'E01090008': `The form of the transaction ID is not correct`,
    'E01100001': `The transaction password is not specified`,
    'E01100008': `The form of the transaction password is not correct`,
    'E01160001': `"PayTimes" is not specified.`,
    'E01110002': `Neither the specified AccessID nor AccessPass does not exist.`,
    'E01160007': `Wrong characters are specified for "PayTimes". Please use numbers only.`,
    'E01110010': `The settlement for this OrderID is not complete`,
    'E01130012': `Card company abbreviation exceeds the maximum bytes`,
    'E01160010': `"2" is not specified for "PayTimes".`,
    'E01170001': `The card number is not specified`,
    'E01170003': `The card number exceeds the maximum character number`,
    'E01170006': `The card number contains characters other than numbers`,
    'E01170011': `Wrong card number digits (It should be from 10 to 16 digits.)`,
    'E01180001': `"Expire" is not specified.`,
    'E01180003': `Wrong "Expire" format (Please make sure this value has to be 4 digits)`,
    'E01180006': `The expire date contains characters other than numbers`,
    'E01180008': `Wrong Format (for "Expire")`,
    'E01190001': `The site ID is not specified`,
    'E01190008': `The form of the site ID is not correct`,
    'E01200001': `The site password is not specified`,
    'E01200008': `The form of the site password is not correct`,
    'E01210002': `Neither the specified SiteID nor SitePass does not exist.`,
    'E01220001': `The member ID is not specified`,
    'E01220005': `The number of digits for "MemberID" exceeds the limit.`,
    'E01220008': `Wrong Format (for "MemberID")`,
    'E01230006': `Wrong characters are specified for "CardSeq". Please use numbers only.`,
    'E01230009': `The number of registered cards reaches a limit of 5 cards.`,
    'E01240002': `The specified card does not exist.`,
    'E01240012': `The specified MemberID duplicates in the uploaded file.`,
    'E01250008': `Wrong Format (for "CardPass")`,
    'E01250010': `Wrong "CardPass" entered by the user.`,
    'E01260001': `"Method" is not specified.`,
    'E01260002': `Wrong value is specified for "Method".`,
    'E01260010': `Either card number or the value set for "Method" is the wrong one.`,
    'E01270001': `"PayTimes" is not specified.`,
    'E01270005': `The number of digits for "PayTimes" exceeds the limit.`,
    'E01270006': `Wrong characters are specified for "PayTimes". Please use numbers only.`,
    'E01270010': `The specified value is not available for "PayTimes".`,
    'E01290001': `HTTP_ACCEPT is not specified.`,
    'E01300001': `HTTP_USER_AGENT is not specified.`,
    'E01310002': `"DeviceCategory" is not specified.`,
    'E01310007': `Wrong value is specified for "DeviceCategory". The available values are "0" or "1".`,
    'E01320012': `The number of bytes for "ClientField1" exceeds the limit.`,
    'E01330012': `The number of bytes for "ClientField2" exceeds the limit.`,
    'E01340012': `The number of bytes for "ClientField3" exceeds the limit.`,
    'E01350001': `"MD" is not specified.`,
    'E01350008': `Wrong format (for MD)`,
    'E01360001': `"PaRes" is not specified.`,
    'E01370008': `"TdTenantName" is not specified.`,
    'E01370012': `The number of bytes for "TdTenantName" exceeds the limit.`,
    'E01390002': `Neither the specified SiteID nor MemberID does not exist.`,
    'E01390010': `The specified "MemberID" has been already used.`,
    'E01400007': `Wrong value is specified for "DeviceCategory". The available values are "0" or "1".`,
    'E01410010': `The specified Order ID is not allowed to be made any change to.`,
    'E01420010': `The provisional sales authorization has expired for the specified Order ID.`,
    'E01430012': `The number of bytes for "MemberName" exceeds the limit.`,
    'E01440008': `Wrong Format (for "DefaultFlag")`,
    'E01450008': `Wrong Format (for "ItemCode")`,
    'E01460008': `Wrong Format (for "SecurityCode")`,
    'E01470008': `Wrong Format (for "SeqMode")`,
    'E01480008': `Wrong Format (for "HolderName")`,
    'E01490005': `The sum of "Amount" and "Tax" exceeds the limit.`,
    'E01500001': `"ShopPassString" is not specified.`,
    'E01500005': `The number of characters for "ShopPassString" is the wrong one. Please make sure that the number of characters should be 32.`,
    'E01500012': `Wrong value is set for "ShopPassString".`,
    'E01510001': `Purchase information string is not specified.`,
    'E01510005': `The number of characters for "CheckString" is the wrong one. Please make sure that the number of characters should be 32.`,
    'E01510010': `Wrong format (for usage date)`,
    'E01510011': `Wrong value is set for usage date.`,
    'E01510012': `There is something wrong with purchase information string.`,
    'E01520002': `Invalid value is set for "UserInfo".`,
    'E01530001': `"RetURL" is not specified.`,
    'E01530005': `The number of characters exceeds the limit for "RetURL".`,
    'E01540005': `The number of characters exceeds the limit for "CancelURL".`,
    'E01550001': `"DateTime" is not specified.`,
    'E01550005': `Wrong format (for DateTime) *It should be in the format of yyyyMMddhhmmss`,
    'E01550006': `Invalid value is set for "DateTime".`,
    'E01590005': `The number of characters exceeds the limit for "ItemCode".`,
    'E01590006': `Invalid value is set for "ItemCode".`,
    'E01600001': `"MemberPassString" is not specified.`,
    'E01600005': `The number of characters exceeds the limit for "MemberPassString".`,
    'E01600012': `Wrong value is set for "MemberPassString".`,
    'E01610005': `The value for "RetryMax" is not from 0 to 99.`,
    'E01610006': `Wrong format (for RetryMax). Please use numbers only.`,
    'E01620005': `The value for "SessionTimeout" is not from 0 to 9999.`,
    'E01620006': `Wrong format (for "SessionTimeout"). Please use numbers only.`,
    'E01630010': `Wrong MemberID is specified.`,
    'E01640010': `Wrong SiteID is specified.`,
    'E01650012': `Wrong ShopID is specified.`,
    'E01660013': `Wrong value is set for "Lang".`,
    'E01670013': `The value set for "Enc" is not supported.`,
    'E01700001': `There is something wrong with the number of parameters.`,
    'E01710001': `Recurring flag is not set for the order.`,
    'E01710002': `The specified transaction type does not exist.`,
    'E01730001': `Bonus payment amount is not specified.`,
    'E01730005': `The number of characters exceeds the limit for bonus payment amount.`,
    'E01730006': `"0000990" is not specified for Item Code.`,
    'E01730007': `Wrong format (for bonus payment amount). Please use numbers only.`,
    'E01740001': `Terminal processing sequence number is not specified.`,
    'E01740005': `The number of characters exceeds the limit for terminal processing sequence number.`,
    'E01740007': `Wrong format (for terminal processing sequence number). Please use numbers only.`,
    'E01750001': `Usage date is not specified.`,
    'E01750008': `Wrong format (for usage date)`,
    'E01800001': `Password is not specified.`,
    'E01800008': `Wrong format (for password)`,
    'E01800010': `Invalid password`,
    'E01800050': `Invalid password (0000 is not available)`,
    'E01810001': `Magnetic stripe type is invalid`,
    'E01810008': `Magnetic stripe type is invalid`,
    'E01820001': `Magnetic stripe info is invalid`,
    'E01820003': `Magnetic stripe info is invalid`,
    'E01820008': `Magnetic stripe info is invalid`,
    'E01840010': `The specified parameters are not sufficient.`,
    'E11010001': `The specified Order ID has already completed its settlement.`,
    'E11010002': `The status cannot be changed for the specified OrderID because this order has not been settled yet.`,
    'E11010003': `The specified "JobCd" is not available for this OrderID. `,
    'E11010010': `The status of this OrderID cannot be changed because it was settled more than 180 days ago.`,
    'E11010011': `Check email link payment call error / setting.`,
    'E11010012': `Check link settlement call error / setting.`,
    'E11010013': `Please stop the transaction error / settlement and notify you that you can not trade.`,
    'E11010014': `Transaction error / The transaction may have been completed.`,
    'E11010017': `Display the system error / transaction failure, please check the situation by asking.`,
    'E11010099': `This card is not available.`,
    'E11010999': `Please stop the member store setting error / settlement and check the setting status of the net bank by asking.`,
    'E11310001': `Link type payment cannot be executed for this OrderID.`,
    'E11310002': `Link type payment cannot be executed for this OrderID.`,
    'E11310003': `Link type payment cannot be executed for this OrderID.`,
    'E11310004': `Link type payment cannot be executed for this OrderID.`,
    'E11310005': `Card registration failed because this MemberID has already registered a card.`,
    'E21010001': `There is something wrong with 3DS authentication. Please try again later.`,
    'E21010007': `There is something wrong with 3DS authentication. Please try again later.`,
    'E21010999': `There is something wrong with 3DS authentication. Please try again later.`,
    'E21020001': `There is something wrong with 3DS authentication. Please try again later.`,
    'E21020002': `3DS authentication was cancelled. Please try again later.`,
    'E21020007': `There is something wrong with 3DS authentication. Please try again later.`,
    'E21020999': `There is something wrong with 3DS authentication. Please try again later.`,
    'E21010201': `Settlment process failed because the card is non-3DS compliant.`,
    'E21010202': `Settlement process failed because the card is non-3DS compliant.`,
    'E31500014': `There is an error in the specified order number (no value)`,
    'E41170002': `Settlement process failed because the card is not available on our system.`,
    'E41170099': `There is something wrong with card number.`,
    'E61010001': `Settlement process failed. Please try again later.`,
    'E61010002': `Invalid card is being used, or there is something wrong with card number.`,
    'E61010003': `Settlement process failed. Please try again later.`,
    'E61020001': `The specified payment method is not available.`,
    'E61030001': `Your request cannot be accepted under the current merchant contract.`,
    'E82010001': `An error occurred and your request was declined.`,
    'E90010001': `Please wait until we complete processing.`,
    'E91099996': `An error occurred. Please ask GMO-PG to confirm the status by informing us of process date & time and the transmitted parameters.`,
    'E91099997': `There is something wrong with the API URL.`,
    'E91019999': `Settlement process failed. Please try again later.`,
    'E91020001': `Timeout occurred. Please try again later.`,
    'E91029998': `Settlement process failed. Please contact the merchant.`,
    'E91029999': `Settlement process failed. Please try again later.`,
    'E91050001': `Settlement process failed.`,
    'E91060001': `An error occurred. Please ask GMO-PG to confirm the status by informing us of process date & time and the transmitted parameters.`,
    'E91099999': `Settlement process failed. Please try again later.`,
    'E92000001': `The order failed to be processed because of heavy traffic. Please try again later.`,
    'E92000002': `The order failed to be processed because of heavy traffic. Please try again later.`,
    'EX1000301': `Settlement process failed. Please enter card number again.`,
    'EX1000302': `Settlement process failed. Please enter card number again.`,
    'EX1000303': `Settlement process failed. Please enter card number again.`,
    'M01001005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01002001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01002002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01002008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01002010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01003001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01003008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01004001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01004002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01004010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01004012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01004013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01004014': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01005001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01005005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01005006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01005011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01006005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01006006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01007001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01007008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01008001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01008008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01009001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01009002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01009005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01009010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01010001': `There is an error in the specified expiration date (no value)`,
    'M01010012': `There is an error in the specified expiration date (no value)`,
    'M01010013': `There is an error in the specified expiration date (no value)`,
    'M01011001': `There is an error in the specified expiration date (no value)`,
    'M01011012': `There is an error in the specified expiration date (no value)`,
    'M01011013': `There is an error in the specified expiration date (no value)`,
    'M01012001': `There is an error in the specified expiration date (no value)`,
    'M01012005': `There is an error in the specified expiration date (no value)`,
    'M01012008': `There is an error in the specified expiration date (no value)`,
    'M01013005': `There is an error in the specified expiration date (no value)`,
    'M01013006': `There is an error in the specified expiration date (no value)`,
    'M01013011': `There is an error in the specified expiration date (no value)`,
    'M01014001': `There is an error in the specified expiration date (no value)`,
    'M01014005': `There is an error in the specified expiration date (no value)`,
    'M01014008': `There is an error in the specified expiration date (no value)`,
    'M01015005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01015008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01016012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01016013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01017012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01017013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01018012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01018013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01019012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01019013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01020012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01020013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01021012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01021013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01022012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01022013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01023012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01023013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01024012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01024013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01025012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01025013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01026012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01026013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01027012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01027013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01028012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01028013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01029012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01029013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01030012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01030013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01031012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01031013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01032012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01032013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01033012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01033013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01034012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01034013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01035012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01035013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01036001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01036012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01036013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01037001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01037005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01037008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01038001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01038005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01038008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01039005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01039008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01039012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01039013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01040005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01040008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01040012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01040013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01041005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01041008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01041012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01041013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01042005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01042011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01043001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01043012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01043013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01044012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01044013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01045012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01045013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01046012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01046013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01047012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01047013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01048005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01048006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01048011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01049012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01049013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01050012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01050013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01051001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01051005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01051011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01052011': `There is an error in the specified expiration date (size error)`,
    'M01053002': `There is an error in the specified expiration date (attribute error)`,
    'M01054001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01054004': `There is an error in the specified expiration date (value error)`,
    'M01054010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01055010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01055011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01056001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01056012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01057010': `There is an error in the specified expiration date (size error)`,
    'M01058002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01058010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01058011': `Rakuten Edy Center service is down`,
    'M01059001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01059005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01059012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01060010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01061001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01061002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01061005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01062001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01062002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01062005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01063001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01063002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01064001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01064003': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01064013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01065001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01065003': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01065013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01066001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01066003': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01066013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01067001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01067003': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01067013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01068001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01068003': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01068013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01069001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01069003': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01069013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01070001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01070002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01071001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01071005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01071006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01073001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01073002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01073004': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01074090': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01074091': `Check the input parameter error / setting.`,
    'M01074101': `Check the input parameter error / setting.`,
    'M01074108': `Check the input parameter error / setting.`,
    'M01075001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01075005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01075013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01076001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01076010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01077005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01077013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01078005': `The designated merchant ID can not be used (not registered)`,
    'M01078010': `The designated merchant ID can not be used (blocked)`,
    'M01079010': `The designated merchant ID can not be used (outside of the applicable period)`,
    'M01080001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01080005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01080013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01081011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01081013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01082001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01082005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01082013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01083001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01083008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01084002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01085001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01085005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01085006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01085010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01085011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01086001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01086005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01086006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01086010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01087012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01087013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01088012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01088013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01089010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01091001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01091010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01092001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01092010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01093001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01093004': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01093010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01094001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01094008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01095010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01096010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01097010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01098010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01100012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01100013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01101001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01105001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01105005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01107001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01107005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01107010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01112001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01112005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01112008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01113001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01113005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01113008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01114005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01114008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01115010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01120001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01120010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01120012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01120013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01121002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01121001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01121005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01121008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01121012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01121013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01122005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01122008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01122012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01122013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01123001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01123005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01123008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01123012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01226012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01226013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01227012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01124001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01124005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01125001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01125005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01126011': `System error 1`,
    'M01127011': `System error 1`,
    'M01160008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01160010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01238001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01238005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01238008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01238010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01239001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01239005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01239008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01240001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01240005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01241001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01241005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01241008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01242001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01242005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01242008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01243010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01128008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01129001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01129005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01129010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01129013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01130008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01130012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01131001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01131005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01131006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01131010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01131011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01133001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01133005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01133006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01134008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01135005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01135010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01135013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01136001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01136005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01137005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01138005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01139005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01140005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01141001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01141005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01141006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01141011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01142005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01142006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01148010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01150001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01150012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01151005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01153005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01153013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01157001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01157005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01158001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01158005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01158006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01201001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01201008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01202001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01202006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01202010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01203001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01203005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01203006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01203010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01204002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01232001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01232005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01232013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01233011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01234010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01235010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01236002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01237011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01250001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01250005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01250012': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01250013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01251001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01251006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01251010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01252001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01252008': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01253001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01253005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01253006': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01253010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01254002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01255011': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01257010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01320005': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01320013': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'M01108012': `System error 2`,
    'M01108013': `System error 2`,
    'M01109012': `System error 2`,
    'M01109013': `System error 2`,
    'M01110012': `System error 2`,
    'M01111012': `System error 2`,
    'M01111013': `System error 2`,
    'M01112012': `System error 2`,
    'M01112013': `System error 2`,
    'M01500001': `Please ask for input parameter error / re-input.`,
    'M01500005': `Please ask for input parameter error / re-input.`,
    'M01500012': `Please ask for input parameter error / re-input.`,
    'M01510001': `Please ask for input parameter error / re-input.`,
    'M01510005': `Please ask for input parameter error / re-input.`,
    'M01510012': `Please ask for input parameter error / re-input.`,
    'M01520002': `Please ask for input parameter error / re-input.`,
    'M01530001': `Please ask for input parameter error / re-input.`,
    'M01530005': `Please ask for input parameter error / re-input.`,
    'M01540005': `Please ask for input parameter error / re-input.`,
    'M01550001': `Please ask for input parameter error / re-input.`,
    'M01550005': `Please ask for input parameter error / re-input.`,
    'M01550006': `Please ask for input parameter error / re-input.`,
    'M01590005': `Please ask for input parameter error / re-input.`,
    'M01590006': `Please ask for input parameter error / re-input.`,
    'M01600001': `Please ask for input parameter error / re-input.`,
    'M01600005': `Please ask for input parameter error / re-input.`,
    'M01600012': `Please ask for input parameter error / re-input.`,
    'M01610005': `Please ask for input parameter error / re-input.`,
    'M01610006': `Please ask for input parameter error / re-input.`,
    'M01620005': `Please ask for input parameter error / re-input.`,
    'M01620006': `Please ask for input parameter error / re-input.`,
    'M01630010': `Please ask for input parameter error / re-input.`,
    'M01640010': `Please ask for input parameter error / re-input.`,
    'M01650012': `Please ask for input parameter error / re-input.`,
    'M01660013': `Please ask for input parameter error / re-input.`,
    'M01670013': `Please ask for input parameter error / re-input.`,
    'M01680001': `Please ask for input parameter error / re-input.`,
    'M01680008': `Please ask for input parameter error / re-input.`,
    'M01690001': `Please ask for input parameter error / re-input.`,
    'M01690002': `Please ask for input parameter error / re-input.`,
    'M01690003': `Please ask for input parameter error / re-input.`,
    'M01700001': `System error 2`,
    'M01701002': `System error 2`,
    'M01702003': `Please ask for input parameter error / re-input.`,
    'M01703001': `System error 2`,
    'M01703005': `System error 2`,
    'M01704005': `System error 2`,
    'M01704006': `System error 2`,
    'M11010099': `Locale validity error`,
    'M11010999': `Please stop the member store setting error / settlement and check the setting status of the net bank by asking.`,
    'M91099999': `System error 3`,
    'E01144001': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'E01144010': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'E01220002': `Mobile Suica Trading Error / Cancel settlement, please notify that you can not trade.`,
    'E61145002': `System error 4`,
    'E61152002': `System error 5`,
    'E61258001': `A merchant ID different from the client certificate information has been specified`,
    '42C010000': `Settlement process failed. Please try again later.`,
    '42C030000': `Settlement process failed. Please try again later.`,
    '42C120000': `Settlement process failed. Please try again later.`,
    '42C130000': `Settlement process failed. Please try again later.`,
    '42C140000': `Settlement process failed. Please try again later.`,
    '42C150000': `Settlement process failed. Please try again later.`,
    '42C500000': `Settlement process failed. Please try again later.`,
    '42C510000': `Settlement process failed. Please try again later.`,
    '42C530000': `Settlement process failed. Please try again later.`,
    '42C540000': `Settlement process failed. Please try again later.`,
    '42C550000': `Settlement process failed. Please try again later.`,
    '42C560000': `Settlement process failed. Please try again later.`,
    '42C570000': `Settlement process failed. Please try again later.`,
    '42C580000': `Settlement process failed. Please try again later.`,
    '42C600000': `Settlement process failed. Please try again later.`,
    '42C700000': `Settlement process failed. Please try again later.`,
    '42C710000': `Settlement process failed. Please try again later.`,
    '42C720000': `Settlement process failed. Please try again later.`,
    '42C730000': `Settlement process failed. Please try again later.`,
    '42C740000': `Settlement process failed. Please try again later.`,
    '42C750000': `Settlement process failed. Please try again later.`,
    '42C760000': `Settlement process failed. Please try again later.`,
    '42C770000': `Settlement process failed. Please try again later.`,
    '42C780000': `Settlement process failed. Please try again later.`,
    '42G020000': `Insufficient card balance`,
    '42G030000': `The card limit has been exceeded`,
    '42G040000': `Insufficient card balance`,
    '42G050000': `The card limit has been exceeded`,
    '42G060000': `Insufficient card balance`,
    '42G120000': `Invalid card`,
    '42G220000': `Invalid card`,
    '42G300000': `Invalid card`,
    '42G420000': `Wrong password`,
    '42G440000': `Wrong security code`,
    '42G450000': `Security code is not entered`,
    '42G540000': `Invalid card`,
    '42G550000': `The card limit has been exceeded`,
    '42G560000': `Invalid card`,
    '42G600000': `Invalid card`,
    '42G610000': `Invalid card`,
    '42G650000': `Wrong card number`,
    '42G670000': `Wrong ItemCode`,
    '42G680000': `Wrong value is set for "Amount"`,
    '42G690000': `Wrong value is set for "Tax"`,
    '42G700000': `Wrong value is set for "Bonus Payment Times"`,
    '42G710000': `Wrong value is set for "Bonus Payment Month"`,
    '42G720000': `Wrong value is set for "Bonus Payment Amount"`,
    '42G730000': `Wrong value is set for "1st month for payment"`,
    '42G740000': `Wrong value is set for "PayTimes"`,
    '42G750000': `Wrong value is set for "Payment Amount for Installment"`,
    '42G760000': `Wrong value is set for the initial payment amount.`,
    '42G770000': `Wrong value is set for processing type`,
    '42G780000': `Wrong value is set for payment type`,
    '42G790000': `Wrong value is set for reference type`,
    '42G800000': `Wrong value is set for cancellation type`,
    '42G810000': `Wrong value is set for cancellation type`,
    '42G830000': `Wrong Expiry Month`,
    '42G920000': `Invalid card`,
    '42G950000': `Invalid card`,
    '42G960000': `Invalid card`,
    '42G970000': `Invalid card`,
    '42G980000': `Invalid card`,
    '42G990000': `Invalid card`,
    'B01000002': `There is an error in the specified user email address (attribute error)`,
    'B01000003': `There is an error in the specified mall email address (attribute error)`,
    'B01000100': `[Settlement Application] There is an error in the designation of affiliated store ID`,
    'B01001011': `[Settlement Application] There is an error in the password specification`,
    'B01001012': `[Settlement Application] There is an error in the specification of the order number`,
    'B01001013': `[Settlement Application] There is an error in the specification of the amount`,
    'B01001014': `[Settlement Application] There is an error in the specification of the user email address`,
    'B01001021': `[Settlement application] There is an error in the specification of the member store email address`,
    'B01001022': `[Settlement application] There is an error in the designation of the bei`,
    'B01001023': `[Settlement application] There is an error in the specification of the customer`,
    'B01001024': `[Settlement application] There is an error in the specification of invoice mail additional information`,
    'B01001031': `[Settlement application] There is an error in the specification of payment completion e-mail additional information`,
    'B01001032': `[Settlement application] There is an error in the specification of the store ྡ`,
    'B01001033': `[Settlement Application] There is an error in the specification of the settlement end notification URL`,
    'B01001034': `[Settlement Application] There is an error in the specification of the expiration date`,
    'B01001035': `[Settlement Application] There is an error in the format of XML`,
    'B01001041': `[Settlement application] HTML error Content received from Rakuten Edy Center is unexpected content`,
    'B01001042': `[Settlement result inquiry] There is an error in the specification of the merchant ID`,
    'B01001043': `[Settlement result inquiry] There is an error in the password specification`,
    'B01001044': `[Settlement result inquiry] There is an error in the specification of the order number`,
    'B01001045': `[Settlement result question] There is an error in the specification of the From date and time`,
    'B01001055': `[Settlement result question] There is an error in the specification of To date and time`,
    'B01001064': `[Settlement result inquiry] There is an error in the specification of the search pattern`,
    'B01001083': `[Settlement result inquiry] XML error`,
    'B01001111': `[Payment result inquiry] HTML error`,
    'B01001112': `HTTP response code received from the center was abnormal (100) HTTP-Status-Continue`,
    'B01001113': `The HTTP response code received from the center was abnormal (101) HTTP-Status-SwitchingProtocol`,
    'B01001114': `The HTTP response code received from the center was abnormal (201) HTTP-Status-Created`,
    'B01001121': `The HTTP response code received from the center was abnormal (202) HTTP-Status-Accepted`,
    'B01001122': `The HTTP response code received from the center was abnormal (203) HTTP-Status-NonAuthoritativ eInfomation`,
    'B01001123': `The HTTP response code received from the center was abnormal (204) HTTP-Status-NoContent`,
    'B01001124': `The HTTP response code received from the center was abnormal (205) HTTP-Status-ResetContent`,
    'B01001125': `The HTTP response code received from the center was abnormal (206) HTTP-Status-PartialContent`,
    'B01002001': `(300) HTTP-Status-Multiple Choices`,
    'B01002010': `(301) HTTP-Status-MovePermanent ly`,
    'B01002011': `(302) HTTP-Status-MovedTempora rily`,
    'B01002012': `The server is blocking`,
    'B01003001': `(303) HTTP-Status-SeeOther`,
    'B01003002': `(304) HTTP-Status-NotModified`,
    'B01003007': `(305) HTTP-Status-UseProxy`,
    'B01003008': `(400) HTTP-Status-BadRequest`,
    'B01003009': `(401) HTTP-Status-Unauthorized`,
    'B01004001': `(402) HTTP-Status-PaymentRequire d`,
    'B01007001': `(403) HTTP-Status-Forbidden`,
    'B01007002': `(404) HTTP-Status-NotFound`,
    'B01007003': `(405) HTTP-Status-MethodNotAllo wed`,
    'B01007004': `(406) HTTP-Status-NotAcceptable`,
    'B01007005': `(407) HTTP-Status-ProxyAuthenticationRequired`,
    'B01007011': `(408) HTTP-Status-RequestTimeout`,
    'B01007021': `(409) HTTP-Status-Conflict`,
    'B01009000': `(410) HTTP-Status-Gone`,
    'B01009001': `(411) HTTP-Status-LengthRequired`,
    'B01009002': `(412) HTTP-Status-PreconditionFail ed`,
    'B01009003': `(413) HTTP-Status-RequestEntityTo oLarge`,
    'B01009004': `(414) HTTP-Status-RequestURITooL ong`,
    'B01009005': `(415) HTTP-Status-UnsupportedMediaType`,
    'B01009006': `(500) HTTP-Status-InternalServerError`,
    'B01009007': `(501) HTTP-Status-NotInplemented`,
    'B01009008': `(502) HTTP-Status-BadGateway`,
    'B01009009': `(503) HTTP-Status-ServiceUnavaila ble`,
    'B01009010': `(504) HTTP-Status-GatewayTime o t`,
    'B01009011': `(505) HTTP-Status-HTTPVersionNotSupported`,
    'B01009012': `Failed to start communication with center`,
    'B01009013': `Failed to start communication with the center (previous resolution)`,
    'B01009014': `Failed to start communication with center (IP Address resolution)`,
    'B01009050': `Failed to start communication with the center (connect)`,
    'B01009051': `An error occurred while communicating with the center`,
    'B01009052': `An error occurred during communication with the center (during reception)`,
    'B01009053': `An error occurred during communication with the center (during transmission)`,
    'B01009054': `The content received from the center (HTTP Heater r) was abnormal`,
    'B01009055': `Failed to start communication with Proxy server`,
    'B01009056': `Failed to start communication with the proxy server (previous resolution)`,
    'B01009057': `Failed to start communication with the proxy server (IP Address resolution)`,
    'B01009100': `Communication start (connect) with Proxy server failed`,
    'B01009101': `An error occurred while communicating with the proxy server`,
    'B01009201': `An error occurred during communication with the Proxy server (during reception)`,
    'B01009202': `An error occurred during communication with the Proxy server (during transmission)`,
    'B01009203': `Received content from Proxy server was abnormal`,
    'B01009204': `An error occurred while initializing SSL communication`,
    'B01009205': `An error occurred during SSL communication handshake`,
    'B01009206': `An error occurred when receiving SSL communication`,
    'B01009300': `An error occurred when sending SSL communication`,
    'B01009301': `An error occurred when reading the definition file (socket definition file)`,
    'B01009302': `An error occurred while reading the definition file (communication definition file)`,
    'B01007600': `An error occurred when reading the definition file (log definition file)`,
    'B01009303': `An internal error of Rakuten Edy payment program has occurred`,
    'B01009304': `An error occurred while interpreting the URL`,
    'B01009305': `An error occurred during character code conversion`,
    'B01009400': `URL protocol error`,
    'B01009401': `Received SIGTERM`,
    'B01009402': `Failed to interpret XML string`,
    'B01009403': `Mail creation failure`,
    'B01009404': `Authentication information fraud`,
    'B01009405': `System connection not possible`,
    'B01009406': `Invalid data`,
    'B01009407': `Non-member or retired member`,
    'B01009408': `Number of registerable cases exceeded`,
    'B01009409': `Settlement request ID duplication`,
    'B01009410': `No registration data`,
    'B01009411': `Temporary invalid member`,
    'B01009412': `XML format illegal`,
    'B01009413': `System error Mobile Suica system internal error`,
    'B01009414': `You will be notified when the Mobile Suica system is stopped for maintenance etc. during system maintenance`,
    'B01009415': `Invalid data type`,
    'B01009500': `UserId / Password does not exist`,
    'B01009501': `Storage Handling Company Code / Payment Code Mismatch`,
    'B01009502': `2 DBC processing agent number / contract case number do not match`,
    'B01009503': `Payment processing company code / payment code do not match`,
    'B01009504': `Error when acquiring key data`,
    'B01009505': `Access was restricted due to a short request overload. Please display / transaction failure and try again.`,
    'B01009600': `Storage process item check error (illegal value)`,
    'B01009601': `Storage process item check error (Payment code not set)`,
    'B01009602': `Storage processing item check error (payment code digit shortage)`,
    'B01009603': `Storage process item check error (reception number not set)`,
    'B01009604': `Storage process item check error (reception number digit missing)`,
    'B01009605': `Storage processing item check error (company code not set)`,
    'B01009606': `Storage processing item check error (company code digit shortage)`,
    'B01009607': `Storage process item check error (phone number not set)`,
    'B01009610': `Storage process item check error (Kanji ྡ not set)`,
    'B01009611': `Storage processing item check error (payment due date not set)`,
    'B01009612': `Storage processing item check error (value other than payment due number)`,
    'B01009613': `Storage processing item check error (payment deadline digit incorrect)`,
    'B01009614': `Storage processing item check error (payment deadline date and time value invalid)`,
    'B01009615': `Storage processing item check error (payment deadline past date invalid)`,
    'B01009616': `Storage processing item check error (payment amount not set)`,
    'B01009617': `Storage processing item check error (payment amount incorrect)`,
    'B01009620': `Storage processing item check error (payment amount ≦ 0)`,
    'B01009621': `Storage processing item check error (payment amount ≦ 0)`,
    'B01009622': `Storage processing item check error (payment amount ≦ 0)`,
    'B01009623': `Storage processing item check error (payment amount ≦ 0)`,
    'B01009624': `Storage processing item check error (payment amount ≦ 0)`,
    'B01009625': `Storage processing item check error (payment amount ≦ 0)`,
    'B01009626': `Storage processing item check error (payment amount> 999999)`,
    'B01009627': `Storage processing item check error (payment amount> 999999)`,
    'B01009628': `Storage processing item check error (payment amount> 999999)`,
    'B01009629': `Storage information duplication error`,
    'B01009630': `Storage information logic deleted error`,
    'B01009700': `Storage process deletion (D) No storage information error`,
    'B01009701': `Storage process deletion (D) Storage information logic deleted error`,
    'B01009702': `Storage process deletion Storage information change impossible error`,
    'B01009900': `Storage DB OPEN error`,
    'B01009901': `Storage DB READ error`,
    'B01009902': `Storage DB INSERT error`,
    'B01009903': `Storage process deletion (D) Storage DB Open error`,
    'B01009904': `Storage process deletion (D) Storage DB Read error`,
    'B01009999': `Storage process deletion (D) Error at storage DB Insert`,
    'S01000002': `Can not get sequence No for mobile payment number`,
    'S01001001': `Storage process deletion (D) The corresponding storage data can not be deleted because it is under query`,
    'S01001002': `Payment processing item check error (payment code not set)`,
    'S01001006': `Payment processing item check error (company code not set)`,
    'S01001007': `Payment processing not received error`,
    'S01001008': `Payment processing unsent data no error`,
    'S01001010': `Payment processing No payment information error`,
    'S01001012': `Payment processing Payment information logic deleted error`,
    'S01001015': `Payment processing READ request payment DB OPEN error`,
    'S01001016': `Payment processing READ request payment DB READ error`,
    'S01009901': `Payment processing READ request payment DBUPDATE error`,
    'S01009902': `Payment processing SEARCH request payment D BOPEN error`,
    'W0100W001': `Payment processing SEARCH request payment D BREAD error`,
    'W0100W002': `Payment processing SEARCH request payment D BUPDATE error`,
    'W0100W003': `Please contact us if there is an internal error by a convenience store payment agent.`,
    'W0100W004': `Expired payment error`,
    'W0100W005': `Please display settlement request error / transaction failure and ask for it.`,
    'W0100W090': `Please display a payment stop request error / transaction failure and ask.`,
    'W0100W092': `Display the merchant setting error / transaction failure, please inquire.`,
    'W0100W600': `Lawson ministop processing request error / Processing failed because the user is in Loppi operation or has been operated.`,
    'W0100W601': `Please display FamilyMart, settlement request error / transaction failure and ask.`,
    'W0100W602': `Display FamilyMart, settlement cancellation request error / transaction failure, please inquire.`,
    'W0100W603': `Please display system error (communication) / transaction failure and ask.`,
    'W0100W604': `Please display 7-Eleven, settlement request error / transaction failure and ask.`,
    'W0100W605': `Please display 7-Eleven · settlement cancellation request error / transaction failure, please contact us.`,
    'W0100W606': `The number of transactions exceeds the monthly maximum.`,
    'W0100W607': `The order schedule is incorrect.`,
    'W0100W608': `The merchant setting is a contract that can not use the authentication option.`,
    'W0100W609': `Return URL is invalid.`,
    'W0100W610': `The URL at the time of cancellation is invalid.`,
    'W0100W611': `Customer ID is invalid.`,
    'W0100W612': `Customer's email address is invalid.`,
    'W0100W613': `The token is invalid.`,
    'W0100W614': `Token is invalid.`,
    'W0100W615': `The token has expired.`,
    'W0100W616': `The billing number is duplicated.`,
    'W0100W617': `The total amount of money for the product is incorrect.`,
    'W0100W640': `The transaction amount limit has been exceeded.`,
    'W0100W641': `The specified trade has been processed.`,
    'W0100W642': `The maximum number of reprocessing attempts has been exceeded.`,
    'W0100W643': `The payment method is invalid.`,
    'W0100W644': `The currency code is invalid.`,
    'W0100W670': `Customer ID is invalid.`,
    'W0100W671': `The payment option is incorrect.`,
    'W0100W672': `The source of funds for the customer is incorrect.`,
    'W0100W673': `Shipping address is invalid.`,
    'W0100W674': `The setting of the merchant is a contract that can not use the API.`,
    'W0100W675': `The total cost of the item is invalid.`,
    'W0100W680': `The shipping allowance is invalid.`,
    'W0100W691': `The total commission fee is invalid.`,
    'W0100W700': `The tax budget is invalid.`,
    'W0100W701': `The item price is incorrect.`,
    'W0100W730': `The item price is invalid.`,
    'W0100W731': `The number of digits in the billing number is over.`,
    'W0100W740': `Some of the item descriptions were omitted.`,
    'W0100W741': `Some free items have been omitted.`,
    'W0100W770': `Approval is pending.`,
    'W0100W771': `The number of digits in the page style is over.`,
    'W0100W772': `The number of digits in the header image URL is over.`,
    'W0100W773': `The number of digits in the notification destination URL is exceeded.`,
    'W0100W774': `Number of digits of identification code is over.`,
    'W0100W775': `I can not continue processing of the specified transaction.`,
    'W0100W853': `Failed to initialize eBay API.`,
    'W0100R156': `An error has occurred in the eBay API.`,
    'W02000001': `There was an error in the eBay communication.`,
    'W02000002': `The number of items is incorrect.`,
    'W02000003': `Order does not exist.`,
    'LW1310004': `eBay connection information is incorrect.`,
    'FM1999001': `Item number and transaction ID are irregular.`,
    'FM1999002': `Invalid eBay connection information.`,
    'D01000001': `Item number is duplicated.`,
    'D01000002': `Item number is duplicated.`,
    'D01000099': `Item number is duplicated.`,
    'SE1990001': `Order ID is duplicated.`,
    'SE1990002': `The specified option has been temporarily disabled.`,
    'P01010202': `Specified option is invalid.`,
    'P01010400': `Specified parameters are not supported.`,
    'P01010401': `Specified parameters are not supported.`,
    'P01010402': `Invalid data.`,
    'P01010404': `The buyer's balance is insufficient.`,
    'P01010405': `The risk management configuration has rejected the transaction.`,
    'P01010406': `The payment was declined due to the risk management settings.`,
    'P01010407': `Approval has been cancelled.`,
    'P01010408': `The approval period has expired.`,
    'P01010409': `The approval period has expired.`,
    'P01010410': `Approval has already been completed.`,
    'P01010411': `The customer account has been restricted.`,
    'P01010412': `We can not continue the approval process.`,
    'P01010413': `Unsupported currency code.`,
    'P01010414': `The transaction has been rejected.`,
    'P01010415': `The approval and withdrawal functions can not be used.`,
    'P01010416': `Transaction ID is invalid.`,
    'P01010417': `The specified amount of money has exceeded the limit.`,
    'P01010418': `The merchant setting is a contract that can not use the approval and withdrawal functions.`,
    'P01010419': `The maximum number available for settlement has been reached.`,
    'P01010420': `The cancellation approval number is incorrect.`,
    'P01010421': `Approval has already been completed.`,
    'P01010422': `The specification method of re-approval is invalid.`,
    'P01010424': `The maximum number of re-authorizations allowed for approval has been reached.`,
    'P01010425': `A reapproval was called during the warranty period.`,
    'P01010426': `The transaction has been canceled or expired.`,
    'P01010427': `The status of the order is canceled, expired, or completed.`,
    'P01010428': `Your order has expired.`,
    'P01010429': `Your order has been cancelled.`,
    'P01010430': `The maximum number of approvals allowed for the order has been reached.`,
    'P01010431': `The transaction has been rejected by the risk model.`,
    'P01010432': `Unsupported parameter.`,
    'P01010433': `The shipping address is incorrect.`,
    'P01010434': `Failed to query shipping address.`,
    'P01010435': `Number of digits is over.`,
    'P01010436': `You can not cancel designated approval, reapprove, or collect.`,
    'P01010437': `Your billing address is incorrect.`,
    'P01010438': `Your billing address is incorrect.`,
    'P01010439': `Your billing address is incorrect.`,
    'P01010440': `Your billing address is incorrect.`,
    'P01010441': `Payment is pending.`,
    'P01010442': `The transaction has been cancelled.`,
    'P01010443': `The cancellation approval number is incorrect.`,
    'P01010444': `The merchant setting is a contract that can not use the approval and withdrawal functions.`,
    'P01010445': `I can not continue to process the transaction.`,
    'P01010446': `The cancellation approval number is incorrect.`,
    'P01010457': `Invalid option.`,
    'P01010458': `There is an error in the specification of the option.`,
    'P01010459': `There is an error in the specification of the option.`,
    'P01010460': `Number of digits in URL is over.`,
    'P01010461': `Payment failed due to hold status.`,
    'P01010462': `The transaction has been returned because an error occurred.`,
    'P01010463': `The item amounts do not match.`,
    'P01010464': `The payment status is incorrect. (None)`,
    'P01010465': `The payment status is incorrect. (Canceled-Reversal)`,
    'P01010467': `The payment status is incorrect. (Denied)`,
    'P01010468': `The payment status is incorrect. (Expired)`,
    'P01010469': `The payment status is incorrect. (Failed)`,
    'P01010470': `The payment status is incorrect. (In-Progress)`,
    'P01010471': `The buyer's balance is insufficient.`,
    'P01010472': `The risk management configuration has rejected the transaction.`,
    'P01010473': `The payment status is incorrect. (Partially-Refunded)`,
    'P01010474': `I can not continue to process the transaction.`,
    'P01010475': `The cancellation approval number is incorrect.`,
    'P01010476': `The payment status is incorrect. (Pending)`,
    'P01010477': `The payment status is incorrect. (Pending)`,
    'P01010478': `The payment status is incorrect. (Pending)`,
    'P01010479': `The payment status is incorrect. (Pending)`,
    'P01010480': `The payment status is incorrect. (Pending)`,
    'P01010481': `The cancellation approval number is incorrect.`,
    'P01010482': `The cancellation approval number is incorrect.`,
    'P01010486': `The payment status is incorrect. (Refunded)`,
    'P01010537': `The payment status is incorrect. (Reversed)`,
    'P01010538': `The payment status is incorrect. (Reversed)`,
    'P01010539': `The payment status is incorrect. (Processed)`,
    'P01010600': `The payment status is incorrect. (Voided)`,
    'P01010601': `The payment status is incorrect.`,
    'P01010602': `Invalid parameter.`,
    'P01010603': `Specified method is not supported.`,
    'P01010604': `No method has been specified.`,
    'P01010605': `Request parameter is not specified.`,
    'P01010606': `Parameter is not specified. (Amt)`,
    'P01010607': `Parameter is not specified. (MaxAmt)`,
    'P01010608': `The specification method of re-approval is invalid.`,
    'P01010609': `Parameter is not specified. (ReturnURL)`,
    'P01010610': `Parameter is not specified. (NotifyURL)`,
    'P01010611': `Parameter is not specified. (CancelURL)`,
    'P01010612': `Parameter is not specified. (ShipToStreet)`,
    'P01010613': `The merchant setting is a contract that can not use the approval and withdrawal functions.`,
    'P01010614': `Parameter is not specified. (ShipToStreet2)`,
    'P01010615': `Parameter is not specified. (ShipToCity)`,
    'P01010616': `Parameter is not specified. (ShipToState)`,
    'P01010617': `Parameter is not specified. (ShipToZip)`,
    'P01010618': `Parameter is not specified. (Country)`,
    'P01010619': `Unsupported parameter.`,
    'P01010620': `Parameter is not specified. (ReqConfirmShipping)`,
    'P01010621': `Parameter is not specified. (No shipping)`,
    'P01010622': `Parameter is not specified. (AddrOverride)`,
    'P01010623': `Parameter is not specified. (LocaleCode)`,
    'P01010624': `We can not continue the approval process.`,
    'P01010625': `The transaction has been rejected.`,
    'P01010626': `Parameter is not specified. (PaymentAction)`,
    'P01010627': `Parameter is not specified. (Email)`,
    'P01010628': `I can not continue to process the transaction.`,
    'P01010629': `Parameter is not specified. (ShipToCity)`,
    'P01010630': `The transaction has been rejected by the risk model.`,
    'P01010725': `Parameter is not specified. (Token)`,
    'P01010726': `Parameter is not specified. (Token)`,
    'P01010727': `Parameter is not specified. (Token)`,
    'P01010728': `Parameter is not specified. (Token)`,
    'P01010729': `Parameter is not specified. (Token)`,
    'P01010730': `Parameter is not specified. (Token)`,
    'P01010731': `Parameter is not specified. (Token)`,
    'P01010736': `Parameter is not specified. (PayerID)`,
    'P01010800': `The payment status is incorrect. (Pending)`,
    'P01011001': `Parameter is not specified. (ItemAmt)`,
    'P01011094': `Parameter is not specified. (ShippingAmt)`,
    'P01011547': `The payment status is incorrect. (Failed)`,
    'P01011601': `Parameter is not specified. (HandlingAmt)`,
    'P01011602': `Parameter is not specified. (HandlingAmt)`,
    'P01011610': `Parameter is not specified. (TaxAmt)`,
    'P01011611': `Parameter is not specified. (IPAddress)`,
    'P01011612': `Parameter is not specified. (ShipToName)`,
    'P01011801': `The payment status is incorrect. (Pending)`,
    'P01011802': `The payment status is incorrect. (Pending)`,
    'P01011803': `The payment status is incorrect. (Pending)`,
    'P01011804': `The payment status is incorrect. (Pending)`,
    'P01011805': `The payment status is incorrect. (Pending)`,
    'P01011806': `The payment status is incorrect. (Pending)`,
    'P01011807': `The payment status is incorrect. (Pending)`,
    'P01011810': `The payment status is incorrect. (Pending)`,
    'P01011811': `The payment status is incorrect. (Pending)`,
    'P01011812': `The payment status is incorrect. (Pending)`,
    'P01011813': `The payment status is incorrect. (Pending)`,
    'P01011814': `The payment status is incorrect. (Pending)`,
    'P01011815': `The payment status is incorrect. (Pending)`,
    'P01011820': `The payment status is incorrect. (Pending)`,
    'P01011821': `Parameter is not specified. (L_Amt)`,
    'P01011822': `Parameter is not specified. (L_TaxAmt)`,
    'P01011823': `Parameter is not specified. (L_TaxAmt)`,
    'P01011824': `Parameter is not specified. (L_TaxAmt)`,
    'P01011825': `Parameter is not specified. (L_TaxAmt)`,
    'P01011826': `The status of the order is canceled, expired, or completed.`,
    'P01011827': `Parameter is not specified. (L_TaxAmt)`,
    'P01011828': `Parameter is not specified. (L_TaxAmt)`,
    'P01011829': `Parameter is not specified. (L_TaxAmt)`,
    'P01011830': `Parameter is not specified. (L_TaxAmt)`,
    'P01011831': `Parameter is not specified. (AuthorizationID)`,
    'P01011832': `Specified parameters are not supported.`,
    'P01012109': `Parameter is not specified. (L_Amt)`,
    'P01012124': `Parameter is not specified. (L_Amt)`,
    'P01012200': `The maximum number available for settlement has been reached.`,
    'P01012201': `Parameter is not specified. (L_TaxAmt)`,
    'P01012202': `Parameter is not specified. (L_TaxAmt)`,
    'P01012203': `Parameter is not specified. (CompleteType)`,
    'P01012204': `Parameter is not specified. (CurrencyCode)`,
    'P01012205': `Parameter is not specified. (L_TaxAmt)`,
    'P01012206': `Parameter is not specified. (L_TaxAmt)`,
    'P01012207': `Parameter is not specified. (L_TaxAmt)`,
    'P01012208': `Parameter is not specified. (TransactionID)`,
    'P01020000': `Parameter is not specified. (TransactionEntity)`,
    'P01020001': `Parameter is not specified. (Acct)`,
    'P01020003': `Parameter is not specified. (ExpDate)`,
    'P01020004': `Parameter is not specified. (FirstName)`,
    'P01020005': `Parameter is not specified. (LastName)`,
    'P01020006': `Parameter is not specified. (Street)`,
    'P01020007': `Parameter is not specified. (Street 2)`,
    'P01020008': `Parameter is not specified. (City)`,
    'P01020009': `Parameter is not specified. (State)`,
    'P01020010': `Parameter is not specified. (Zip)`,
    'P01020011': `Parameter is not specified. (CountryCode)`,
    'P01020012': `Parameter is not specified. (RefundType)`,
    'P01029999': `Parameter is not specified. (StartDate)`,
    'P01081000': `Parameter is not specified. (EndDate)`,
    'P01081001': `Parameter is not specified. (EndDate)`,
    'P01081002': `Parameter is not specified. (MPID)`,
    'P01081003': `Parameter is not specified. (CreditCardType)`,
    'P01081004': `Parameter is not specified. (User)`,
    'P01081100': `Parameter is not specified. (Pwd)`,
    'P01081101': `Parameter is not specified. (Version)`,
    'P01081102': `Invalid parameter. (Amt)`,
    'P01081103': `Invalid parameter. (MaxAmt)`,
    'P01081104': `Invalid parameter. (NotifyURL)`,
    'P01081105': `Invalid parameter. (ShipToStreet)`,
    'P01081106': `Invalid parameter. (ShipToStreet2)`,
    'P01081107': `Invalid parameter. (ShipToCity)`,
    'P01081108': `Invalid parameter. (ShipToState)`,
    'P01081109': `Invalid parameter. (ShipToZip)`,
    'P01081110': `Invalid parameter. (Country)`,
    'P01081111': `Invalid parameter. (ReqConfirmShipping)`,
    'P01081112': `Invalid parameter. (Noshipping)`,
    'P01081113': `Invalid parameter. (AddrOverride)`,
    'P01081114': `Invalid parameter. (LocaleCode)`,
    'P01081115': `Invalid parameter. (PaymentAction)`,
    'P01081116': `Invalid parameter. (ItemAmt)`,
    'P01081117': `Invalid parameter. (ShippingAmt)`,
    'P01081118': `Invalid parameter. (HandlingTotal Amt)`,
    'P01081119': `Invalid parameter. (TaxAmt)`,
    'P01081120': `Invalid parameter. (IPAddress)`,
    'P01081121': `Invalid parameter. (ShipToName)`,
    'P01081122': `Invalid parameter. (L_Amt)`,
    'P01081123': `Invalid parameter. (L_TaxAmt)`,
    'P01081124': `Invalid parameter. (CompleteType)`,
    'P01081125': `Invalid parameter. (CurrencyCode)`,
    'P01081126': `Parameter is not specified. (Pwd)`,
    'P01081127': `Invalid parameter. (TransactionEntity)`,
    'P01081128': `Invalid parameter. (ExpDate)`,
    'P01081129': `Invalid parameter. (FirstName)`,
    'P01081130': `Invalid parameter. (LastName)`,
    'P01081131': `Invalid parameter. (Street)`,
    'P01081132': `Invalid parameter. (Street 2)`,
    'P01081133': `Invalid parameter. (City)`,
    'P01081134': `Invalid parameter. (RefundType)`,
    'P01081135': `Invalid parameter. (StartDate)`,
    'P01081136': `Invalid parameter. (EndDate)`,
    'P01081137': `Invalid parameter. (CreditCardType)`,
    'P01081138': `Invalid parameter. (Username)`,
    'P01081139': `Invalid parameter. (Password)`,
    'P01081140': `Invalid parameter. (Version)`,
    'P01081141': `An internal error has occurred.`,
    'P01081142': `Communication with the PayPal Center has failed.`,
    'P01081143': `The user has canceled the PayPal payment operation.`,
    'P01081144': `Notification code error`,
    'P01081145': `Transaction Existence Error`,
    'P01081146': `Double reception error`,
    'P01081147': `Status error`,
    'P01081148': `Usage stop error`,
    'P01081149': `Amount mismatch error`,
    'P01081150': `Tax shipping mismatch error`,
    'P01081200': `Settlement date error`,
    'P01081201': `I refused to accept it at the CAFIS Center.`,
    'P01081203': `I refused to accept at the card company.`,
    'P01081205': `If you entered the product code incorrectly.`,
    'P01081206': `An expired credit card has been entered.`,
    'P01081207': `You have entered a card without a contract at the CAFIS Center.`,
    'P01081208': `It is when the operation of the corresponding business of the credit company center is finished.`,
    'P01081209': `It is not a target business of the connected credit company center.`,
    'P01081210': `It is a place of reception refusal to the connection request and sending center.`,
    'P01081211': `It is the place of the mobile phone not corresponding to the Internet payment service.`,
    'P01081212': `It is a place outside the merchant contract term.`,
    'P01081213': `You can not connect to the certification support center.`,
    'P01081214': `A pictogram is specified for a member store, and the character string for pictograph conversion can not be converted in binary.`,
    'P01081215': `If the processing duration period has been exceeded.`,
    'P01081219': `You have entered an expired credit card.`,
    'P01081220': `It is a place where a credit card that can not be handled by the card company's capital is entered.`,
    'P01081221': `If the security code entered by you is wrong.`,
    'P01081222': `The response to the settlement notification from the certification support center is invalid.`,
    'P01081223': `Received conditional success at the certification support center. It is the case that you have settled again for the transaction that has already been settled.`,
    'P01081224': `SSL server certificate authentication error.`,
    'P01081225': `If an error occurs during Felica processing, if you can not connect to the certification support center, or if you select the contents of the payment and return without executing.`,
    'P01081226': `Settlement date error`,
    'P01081227': `The area issue of iD application has not been completed.`,
    'P01081229': `There is no card available.`,
    'P01081230': `You can not pay with iD because the password error has exceeded the default number.`,
    'P01081232': `There is a possibility that the IC card lock is on or something more has happened during communication.`,
    'P01081234': `It is the processing number and the processing number which were processed last time.`,
    'P01081235': `If you fail to read card information.`,
    'P01081236': `The Felica chip has been updated by other processes while processing the net payment.`,
    'P01081237': `You have chosen a credit card that you can not handle.`,
    'P01081238': `If you can not connect to the certification support center, or if you need to upgrade the iD application version.`,
    'P01081239': `[Settlement request] An error occurred in the communication parameters with the subsequent settlement center. (Message digest)`,
    'P01081243': `[Settlement Request] This is a connection that is not permitted by the Subsequent Settlement Center.`,
    'P01081244': `[Settlement request] Execution of the settlement module in the subsequent settlement center has failed.`,
    'P01081245': `[Settlement request] An error occurred in the communication parameters with the subsequent settlement center. (Receive parameter)`,
    'P01081247': `[Settlement request] Communication with the subsequent settlement center has failed.`,
    'P01081248': `[Settlement results received] An error occurred in the communication parameters with the subsequent settlement center. (Receive parameter)`,
    'P01081249': `[Settlement results received] Heavy deposit has occurred at the subsequent settlement center.`,
    'P01081250': `[Settlement results received] An internal error has occurred. (transition)`,
    'P01081251': `[User Canceled Reception] A notification has been received that the payment operation of the user has been canceled for the transaction that has already been deposited.`,
    'P02000001': `[User cancellation reception] An internal error has occurred. (transition)`,
    'P02000002': `[User cancellation reception] An internal error has occurred. (transition)`,
    'P03000003': `[Settlement request] The cancellation of the fault was implemented at the subsequent settlement center.`,
    'N01001001': `[Settlement request] An error occurred in au Easy OpenID linkage cancellation.`,
    'N01001002': `[Operation cancellation] The lady canceled the payment by au easy settlement.`,
    'N01001003': `It is a transaction without permission to execute.`,
    'N01001004': `Not a valid user.`,
    'N01001005': `Authorization cancellation has been performed.`,
    'N01001006': `Sales cancellation is taking place.`,
    'N01001007': `The amount of money exceeds the limit.`,
    'N01001008': `It is not a valid credit card.`,
    'N01001009': `It is not a valid credit card.`,
    'N10000001': `[Operation cancellation] The lady canceled the payment by au easy settlement.`,
    'N0C030C01': `A system error has occurred at the subsequent center.`,
    'N0C030C03': `A system error has occurred at the subsequent center.`,
    'N0C030C12': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030C13': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030C14': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030C15': `A system error has occurred at the subsequent center.`,
    'N0C030C16': `A system error has occurred at the subsequent center.`,
    'N0C030C33': `A system error has occurred at the subsequent center.`,
    'N0C030C34': `A system error has occurred at the subsequent center.`,
    'N0C030C49': `A system error has occurred at the subsequent center.`,
    'N0C030C50': `A system error has occurred at the subsequent center.`,
    'N0C030C51': `A system error has occurred at the subsequent center.`,
    'N0C030C53': `A system error has occurred at the subsequent center.`,
    'N0C030C54': `A system error has occurred at the subsequent center.`,
    'N0C030C55': `A system error has occurred at the subsequent center.`,
    'N0C030C56': `A system error has occurred at the subsequent center.`,
    'N0C030C57': `A system error has occurred at the subsequent center.`,
    'N0C030C58': `A system error has occurred at the subsequent center.`,
    'N0C030C60': `A system error has occurred at the subsequent center.`,
    'N0C030G03': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G12': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G30': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G54': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G55': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G56': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G60': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G61': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G65': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G67': `[Payment confirmation] Not a valid user.`,
    'N0C030G83': `Not a valid user.`,
    'N0C030G85': `A processing cancellation error occurred at the following center, and a valid initial charge remained.`,
    'N0C030G95': `[Settlement request] Finalization has failed in the subsequent settlement center.`,
    'N0C030G96': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G97': `[Settlement request] Cancel processing has failed at the subsequent settlement center.`,
    'N0C030G98': `[Cancellation request] Cancellation processing failed in the subsequent settlement center.`,
    'N0C030G99': `[Settlement Canceled] Princess has canceled docomo Keitai.`,
    'N0N010007': `[Payment failure] DOCOMO mobile phone payment has failed.`,
    'N0N010008': `[Payment failure] DOCOMO mobile phone payment has failed.`,
    'N0N010009': `[Payment failure] DOCOMO mobile phone payment has failed.`,
    'N0N010013': `[Settlement Canceled] Mr. Lady has canceled the application for docomo continuous billing.`,
    'N0N010024': `[Cancel change] Mr. Lady has canceled the change of docomo continuous billing.`,
    'N0N010032': `[Stop Cancel] Mr. Lady has canceled the end of DOCOMO continuous billing.`,
    'N0N020014': `[Payment failure] The application for DOCOMO continuous billing has failed.`,
    'N0N020017': `[Failed to change] Change of DOCOMO continuous charge has failed.`,
    'N0N020018': `[Failed to finish] The end of DOCOMO continuous billing has failed.`,
    'N0N020019': `[Failed to finish] The end of DOCOMO continuous billing has failed.`,
    'N0N020020': `[Failed to finish] The end of DOCOMO continuous billing has failed.`,
    'N0N020021': `[Failed to finish] The end of DOCOMO continuous billing has failed.`,
    'N0N020022': `[Failed to finish] The end of DOCOMO continuous billing has failed.`,
    'N0N020023': `[Failed to finish] The end of DOCOMO continuous billing has failed.`,
    'N0N030038': `[Increase request] In the subsequent settlement center, increase processing has failed.`,
    'N0N040014': `[Payment failure] The application for DOCOMO continuous billing has failed.`,
    'N0K040026': `[Cancellation request, settlement cancellation] Mr. Softbank collectively canceled payment (B) or cancellation processing failed.`,
    'N0K040027': `[Cancellation request, settlement cancellation] Mr. Softbank collectively canceled payment (B) or cancellation processing failed.`,
    'N0K040028': `[Cancellation request, settlement cancellation] Mr. Softbank collectively canceled payment (B) or cancellation processing failed.`,
    'N0K040029': `[Payment failure] Softbank collectively payment (B) failed.`,
    'N0N040031': `[Cancel change] Mr. Lady has canceled the change of docomo continuous billing.`,
    'N0K040037': `[Payment failure] Settlement failed in the subsequent settlement center.`,
    'N0T000001': `[Settlement cancellation] Mr. Ohjima has canceled the bank settlement.`,
    'N0T000002': `[Settlement Failure] Settlement failed due to a discrepancy in the settlement at the subsequent settlement center.`,
    'N0T000003': `[Payment failure] Settlement failed due to an unknown error at the subsequent settlement center.`,
    'N0T000004': `[Payment failure] An unexpected error code has been returned.`,
    'N0T000005': `Insufficient funds`,
    'N0T000006': `Over payment amount`,
    'N0T000007': `Not activated`,
    'N0T000008': `Before start of use`,
    'N0T000009': `Authentication number error`,
    'N0T000010': `Invalid card`,
    'WM1000001': `Membership number error`,
    'WM1000002': `Expiration date error`,
    'WM1000003': `Non-serviceable card: Pass code error`,
    'WM1000004': `Non-serviceable card: Outside alliance period`,
    'WM1000005': `Non-serviceable card: Alliance invalid`,
    'WM1000006': `Non-serviceable card: Alliance authorized transaction not included`,
    'WM1000007': `Out of Service Card: Other Alliance Transaction Error`,
    'WM1000008': `Non-serviceable card: JCB center company unregistered error`,
    'WM1000009': `Out of Service Card: JCB POS Branch Check Error`,
    'WM1000010': `Out of Service Card: JCB Merchant Valid Error`,
    'AU1000001': `Non-serviceable card: Alliance invalid`,
    'AU1000002': `Non-serviceable card: Outside alliance period`,
    'AU1000003': `Out of Service Card: JET'S Terminal Error`,
    'AU1000004': `Cancellation target transaction error: No cancellation target transaction`,
    'AU1000005': `Cancellation target transaction error: already canceled`,
    'AMPL20003': `Cancellation target transaction error: The cancellation target transaction is not immediate`,
    'AMPL30026': `Cancellation target transaction error: Cancelable time exceeded`,
    'AMPL40004': `Cancellation target transaction error: Other cancellation target transaction errors`,
    'AMPL40006': `Applicable company target business error: System error`,
    'AMPL40104': `Connection request Company acceptance refusal: Issuer code error`,
    'AMPL40505': `Connection request Company acceptance refusal: Issuer invalid`,
    'AMPL40506': `Connection request company acceptance refusal: Expiry date indicator is invalid`,
    'AMPL90000': `Connection request company acceptance refusal: Expiry date indicator is invalid`,
    'AU1000006': `Connection request Company acceptance denial: Request validation error`,
    'AU2000007': `Connection request company acceptance denial: authentication key mismatch`,
    'AMPL35000': `Connection request company acceptance denial: Authentication key is not valid time`,
    'AMPL40010': `Connection request Company acceptance denial: IP address error`,
    'DC1000001': `Connection request company acceptance denial: Other connection request error`,
    'DC1000002': `Cancelable transaction error: Failure cancelable is not immediate`,
    'DC1000003': `Cancelable transaction error: Failure cancelable time exceeded`,
    'DC1000004': `Canceled Transaction Error: Other Canceled Transaction Error`,
    'DC1000005': `Unforeseen error`,
    'DC1000006': `Communication failure with JCB Prika Settlement Center`,
    'DC1000007': `Invalid return value from JCB Prika Settlement Center`,
    'DC1000008': `Daily limit exceeded`,
    'DC1000009': `One time limit over limit`,
    'DC1000010': `Transaction ID check error`,
    'DC1000011': `Transaction existence check error`,
    'SB1000001': `Connection request company acceptance denial: Other connection request error`,
    'SB1000002': `Token check error`,
    'SB1000004': `State transition check error (payment completed)`,
    'SB1000005': `Non-serviceable card: Alliance invalid`,
    'J01000001': `State transition check error (expired)`,
    'J01000002': `State transition check error (illegal transition)`,
    'J01000003': `Expired`,
    'J01100001': `State transition error`,
    'J01100002': `Payment NG`,
    'JP1000001': `MD5 check error`,
    'JP1000002': `Payment information acquisition error`,
    'JP1000003': `Settlement result parameter check error (presence or absence of settlement date for settlement result)`,
    'JP1000004': `Transition to URL at the time of purchase information content check error`,
    'JP1000005': `Settlement inconsistencies (results notification for transactions for which settlement failed)`,
    'JP1000006': `Shop identification not possible`,
    'JP1000007': `SCD not set`,
    'JP1000008': `Usage stop check error`,
    'JP1000009': `There is no linked transaction (Purchase information output)`,
    'JP1000010': `There is no linked transaction (payment result notification)`,
    'JP1000011': `State transition check error (illegal transition)`,
    'JP1000012': `State transition check error (settled)`,
    'JP1000013': `No purchase information`,
    'JP1000014': `No purchase information`,
    'JP1000015': `Settlement disorder error`,
    'JP1000016': `Other error`,
    'JP1000017': `System error (* 1)`,
    'JP1000018': `System error`,
    'JP1000019': `It is not refundable because the refundable date has passed.`,
    'JP1000020': `The maximum number of transactions that can be queried has been exceeded (100). Please check the occurrence time and call parameters and ask.`,
    'JP1000021': `Payment has expired`,
    'JP1000022': `The merchant's configuration information is incorrect.`,
    'JP1000023': `There is a defect in the payment method selected by the user. Please check with the user.`,
    'JP1000024': `There is a defect in the payment method selected by the user. Please check with the user.`,
    'JP1000025': `There is a defect in the payment method selected by the user. Please check with the user.`,
    'JP1000026': `User information is invalid. Please check with the user.`,
    'JP1000027': `User information is invalid. Please check with the user.`,
    'JP1000028': `User information is invalid. Please check with the user.`,
    'JP1000029': `User information is invalid. Please check with the user.`,
    'JP1000030': `User information is invalid. Please check with the user.`,
    'JP1000031': `User information is invalid. Please check with the user.`,
    'JP1000032': `User information is invalid. Please check with the user.`,
    'JP1000033': `LINE Pay internal error. Please check the occurrence time and call parameters and ask.`,
    'JP1000034': `System internal error. Please check the occurrence time and call parameters and ask.`,
    'JP1000035': `Reception error (communication message error)`,
    'JP1000036': `Reception error (processing deadline exceeded)`,
    'JP1000037': `Ginkgo error (request failure) Actual sales / return / cancel request failed. Ginko's internal error. Please check the occurrence time and call parameters and ask.`,
    'JP1000038': `Ginkgo Error (Other) It is an internal error of Ginkgo. Please check the occurrence time and call parameters and ask.`,
    'JP1000039': `Failed to create billing data at the beginning of the month.`,
    'JP1000040': `Failed to confirm billing data on billing day.`,
    'JP1000041': `Failed to confirm billing data on billing day.`,
    'JP1000042': `Failed to confirm billing data on billing day.`,
    'JP1000043': `Failed to confirm billing data on billing day.`,
    'JP1000044': `The first charge at the time of charge application failed.`,
    'JP1000045': `Cancel refund request failure`,
    'JP1000046': `State transition check error (registered)`,
    'JP1000047': `State transition check error (registered)`,
    'JP1000048': `No purchase information`,
    'JP1000049': `Failed to apply for billing.`,
    'JP1000050': `Processing failed due to user cancellation.`,
    'JP1000051': `Input parameter error / specified transaction invalid`,
    'JP1000052': `Input parameter error / incorrect amount`,
    'NC1000001': `Input parameter error / card number not specified`,
    'NC1000002': `Input parameter error / card number digit excess`,
    'NC1000003': `Input parameter error / Card number digit range invalid`,
    'NC1000004': `Input parameter error / other than card number value`,
    'NC1000005': `Input parameter error / card expiration date not specified`,
    'NC1000006': `Input parameter error / card expiration date exceeded`,
    'NC1000007': `Input parameter error / other than card expiration date`,
    'NC1000008': `Input parameter error / Execution mode digit number excess`,
    'NC1000009': `Input parameter error / billing information presence judgment flag incorrect format`,
    'NC1000010': `Input parameter error / User ID digit number excess`,
    'NC1000011': `Input parameter error / card number of digits exceeded`,
    'NC1000012': `Input parameter error / card definition incorrect format`,
    'NC1000013': `Input parameter error / billing customer's last digit exceeded`,
    'NC2000001': `Input parameter error / billing customer address exceeded one digit`,
    'NC2000002': `Input parameter error / billing customer address exceeded 2 digits`,
    'NC2000003': `Input parameter error / billing customer address exceeded 3 digits`,
    'NC2000005': `Input parameter error / billing customer exceeding prefecture digit number`,
    'NC2000006': `Input parameter error / billing customer postal code excess digits`,
    'NC2000007': `Input parameter error / billing customer postal code format incorrect`,
    'RI1000001': `Input parameter error / billing customer's phone number excess digits`,
    'RI1000002': `Input parameter error / card expiration date not specified`,
    'RI1000003': `Input parameter error / non billing customer number`,
    'RI1000004': `Input parameter error / billing customer email address excess digits`,
    'RI1000005': `Input parameter error / card number not specified`,
    'RI1000006': `Input parameter error / card number digit excess`,
    'RI1000007': `Input parameter error / billing customer email address format incorrect`,
    'RI1000008': `Input parameter error / Execution mode digit number excess`,
    'RI1009999': `Input parameter error / end user IP address format incorrect`,
    'RI1000009': `Input parameter error / Repeater flag format incorrect`,
    'RI2000100': `Input parameter error / Elapsed days after registration of user ID Digits exceeded`,
    'LP1000001': `Input parameter error / billing customer's phone number excess digits`,
    'LP1000002': `Input parameter error / card expiration date not specified`,
    'LP1000003': `Input parameter error / non billing customer number`,
    'LP1001163': `Input parameter error / other than the number of days elapsed since user ID registration`,
    'LP1001177': `Input parameter error / shipping address information judgment flag incorrect format`,
    'LP1001180': `Input parameter error / Delivery destination number of digits exceeded`,
    'LP1009001': `Input parameter error / shipping destination surname surpasses the number of digits`,
    'LP1009002': `Input parameter error / shipping address exceeded one digit`,
    'LP1009003': `Input parameter error / shipping address 2 digit excess`,
    'LP2009900': `Input parameter error / Shipment address exceeded 3 digits`,
    'LP2009999': `Input parameter error / shipping destination prefecture digit excess`,
    'UP1000001': `Input parameter error / billing customer's phone number excess digits`,
    'UP1000002': `Input parameter error / card expiration date not specified`,
    'UP1000003': `Input parameter error / non billing customer number`,
    'UP1000004': `Input parameter error / shipping destination zip code excess digits`,
    'UP1000005': `Input parameter error / shipping destination postal code format incorrect`,
    'UP1008000': `Input parameter error / Member store excess digit number excess`,
    'UP1009900': `Input parameter error / Member store ྡ form invalid`,
    'SC1000001': `Input parameter error / device information digit number excess`,
    'SC1000002': `Input parameter error / Repurchase days digit exceeded`,
    'SC1000003': `Other than input parameter error / repurchase days`,
    'SC1000004': `Input parameter error / past purchase number of digits exceeded`,
    'SC1000005': `Input parameter error / billing customer's phone number excess digits`,
    'SC1000006': `Input parameter error / card expiration date not specified`,
    'SC1000007': `Input parameter error / other than the past purchase count value`,
    'SC1000008': `Input parameter error / Credit result format incorrect`,
    'SC1000009': `Input parameter error / other than the past purchase count value`,
    'SC1000010': `Input parameter error / billing customer's phone number excess digits`,
    'SC1000011': `Input parameter error / shipping destination prefecture digit excess`,
    'SC1000012': `Input parameter error / Credit result format incorrect`,
    'SC1000013': `Input parameter error / shipping destination prefecture digit excess`,
    'SC1000014': `Input parameter error / Post office · sales office flag incorrect format`,
    'SC1000015': `Input parameter error / Post office · Sales office excess digits`,
    'SC2000001': `Input parameter error / device information digit number excess`,
    'SC2000002': `Input parameter error / Repurchase days digit exceeded`,
    'M01058004': `Input parameter error / user point balance digit excess`,
    'M01055001': `Other than input parameter error / user point balance number`,
    'M01199001': `Input parameter error / card registration change number of digits exceeded`,
    'M01199005': `Other than input parameter error / card registration change number value`,
    'M01199011': `Input parameter error / product information repeated number of digits excess`,
    'M01199006': `Input parameter error / other than product information repetition number numerical value`,
    'M01200001': `Input parameter error / product number digit excess`,
    'M01200005': `Other than input parameter error / item number`,
    'M01200006': `Input parameter error / item identification code digit number excess`,
    'M01228005': `Input parameter error / product identification code incorrect format`,
    'M01161008': `Input parameter error / commodity IAN / JAN code digit excess`,
    'M01162005': `Input parameter error / product IAN / JAN code incorrect`,
    'M01163005': `Input parameter error / Product category digit excess`,
    'M01163008': `Input parameter error / unit price digit excess`,
    'M01164005': `Input parameter error / other than unit price number`,
    'M01165005': `Input parameter error / product number of digits excess`,
    'M01166005': `Input parameter error / over 10 item number overruns`,
    'M01167005': `Input parameter error / over 10 item number overruns`,
    'M01168005': `Input parameter error / over-fill item over 19 digits`,
    'M01169005': `Input parameter error / over 20 items in excess`,
    'M01169008': `Input parameter error / excellent item other than 20 numbers`,
    'M01170005': `Input parameter error / over-fill item over 21 digit number`,
    'M01170006': `Input parameter error / Excess item over 22 digit number`,
    'M01171005': `Input parameter error / overrun item over 23 digits`,
    'M01171008': `Input parameter error / over 24 items in excess`,
    'M01172008': `Input parameter error / over 25 items in excess`,
    'M01173008': `Input parameter error / currency code digit excess`,
    'M01174005': `Input parameter error / incorrect currency code format`,
    'M01174006': `Input parameter error / billing customer exceeded number of digits`,
    'M01175008': `Input parameter error / Billing customer country format incorrect`,
    'M01176005': `Input parameter error / message type excess digits`,
    'M01177005': `Transaction existence check error`,
    'M01178005': `Request falsification check error`,
    'M01179005': `Recruit easy payment end reception: State transition error`,
    'M01180005': `Payment failure error`,
    'M01181005': `Request Parameter Abnormal In the Subsequent Settlement Center, request parameters are returned if they differ from the specifications.`,
    'M01182005': `Processing status error In a subsequent settlement center, this occurs when the status is not for processing.`,
    'M01182008': `Failed to refund processing. It occurs when the amount to be refunded is greater than the payment amount at the subsequent settlement center, or the repayment period has passed.`,
    'M01183005': `Point full settlement error point This occurs when the follow-up settlement center can not accept processing because of full settlement.`,
    'M01183008': `Credit card error Occurs when credit card credit acquisition fails.`,
    'M01184005': `Recruit easy payment settlement result reception status check error`,
    'M01185005': `Recruit communication error`,
    'M01185006': `Recruit easy payment settlement result reception input parameter error`,
    'M01186005': `Recruit easy payment settlement result receive transaction existence check error`,
    'M01186006': `API server exception It is an internal error of the subsequent settlement center. Please check the occurrence time and call parameters and ask.`,
    'M01187008': `No data error This error occurs when there is no data that matches the request parameter in the subsequent settlement center.`,
    'M01188008': `Maintenance during maintenance It occurs when maintenance is in progress in the subsequent settlement center and processing can not be accepted.`,
    'M01189005': `Execution permission error This error occurs when the API can not accept processing because you do not have permission to execute the API.`,
    'M01190005': `Shop ID check error This error occurs when you accept a shop ID that does not exist in the subsequent settlement center.`,
    'M01190006': `Total amount out of range error This error occurs when the total amount exceeds the number of significant digits in the subsequent settlement center.`,
    'M01191005': `Order ID check error This error occurs when you receive an order ID that does not exist in the subsequent settlement center.`,
    'M01191006': `Other system error`,
    'M01192005': `Recruit simple payment continued billing end received: status transition error`,
    'M01192006': `Unhandled error This occurs when the purchaser is unable to accept processing, such as the purchaser is on the blacklist, at a subsequent settlement center.`,
    'M01193005': `Continuation charge failure error This occurs when a continual charge fails in the subsequent settlement center.`,
    'M01193006': `Continuation charge failure Forced cancellation In the case of a settlement center, it occurs when continual charge fails and is forcibly canceled.`,
    'M01194005': `Continuing charge failed because of cancellation.`,
    'M01194008': `Recruit simple payment continuation charge result reception status check error`,
    'M01195005': `Recruit easy continuation charge actual sales error`,
    'M01195008': `Recruit simple continuation charge Actual cancellation failure After cancellation error`,
    'M01196005': `Recruit simple continuation charge result receive transaction existence check error`,
    'M01197005': `Merchant ID check error This error occurs when you receive a merchant ID that does not exist in the subsequent settlement center.`,
    'M01197006': `Product ID check error This error occurs when you receive a product ID that does not exist in the subsequent settlement center.`,
    'M01198005': `Item amount check error This error occurs when you receive an item amount that does not exist in the subsequent settlement center.`,
    'M01205005': `Order No., Contract No. Check Error This error occurs when you receive an order No. (Contract No.) that does not exist in the Subsequent Settlement Center.`,
    'M01206005': `There is a defect in the bank transfer (virtual account) department of the shop settings.`,
    'M01207005': `The feature is only available with a proprietary account contract.`,
    'M01208005': `There is no virtual account available.`,
    'M01208006': `Expiration days required error`,
    'M01209005': `Expiration day digits exceeded`,
    'M01210005': `Expiration days format error`,
    'M01211005': `Number of digits for transaction open`,
    'M01212005': `Transaction free prohibition character check error`,
    'M01213005': `Transfer requester Mr. number of digits over`,
    'M01229005': `Transfer requester Mr. ྡ prohibition character check error`,
    'M01229008': `Email address digit over`,
    'M01230005': `Email address format error`,
    'M01230008': `The specified account is in use. (Not in unused state)`,
    'M01231005': `Continuation account ID required error`,
    'RC1000001': `Input parameter error / billing customer's phone number excess digits`,
    'RC1000002': `Input parameter error / card expiration date not specified`,
    'RC1000003': `Input parameter error / non billing customer number`,
    'RC1000005': `Input parameter error / card number not specified`,
    'RC1000006': `The specified account ID does not exist.`,
    'RC1000007': `Account ID input digit number over`,
    'RC1000008': `You are trying to assign an account with an ongoing account status error assignment, or release a released account.`,
    'RC1000009': `Continuation account ID prohibition character error`,
    'RC1000101': `Bank code required error`,
    'RC1000109': `Bank code digit number over`,
    'RC1000110': `Bank code format error`,
    'RC1000111': `Branch code required error`,
    'RC1000112': `Branch code digit number over`,
    'RC2000001': `Branch code format error`,
    'RC2000002': `Subject required error`,
    'RC2000009': `Subject format error`,
    'RC2000010': `Account number required error`,
    'RC2000102': `Account number digit number over`,
    'RC2000103': `Account number format error`,
    'RC2000104': `Payment history existence check error There is no payment history.`,
    'RC2000105': `Account Information Entry Unauthorized continuing account ID or account information (bank code, branch code, item code, account number) Please specify either.`,
    'RC2000106': `Input parameter error / Execution mode not specified`,
    'RC2000107': `Input parameter error / Execution mode incorrect format`,
    'RC2000108': `Input parameter error / order number not specified`,
    'RC2009999': `Input parameter error / Order number digit excess`,
    'RC3000001': `Input parameter error / billing customer's phone number excess digits`,
    'RC3000002': `Input parameter error / card expiration date not specified`,
    'RC3000003': `Input parameter error / non billing customer number`,
    'RC3000005': `Input parameter error / card number not specified`,
    'RC3000006': `The specified account ID does not exist.`,
    'RC3000007': `Account ID input digit number over`,
    'RC3000008': `Input parameter error / Order number format incorrect`,
    'RC3000009': `Continuation account ID prohibition character error`,
    'RC3000110': `Bank code digit number over`,
    'RC3000111': `Bank code format error`,
    'RC3000112': `Input parameter error / duplicate order number (specify already used order number)`,
    'RC3000113': `Input parameter error / Product not specified`,
    'RC3000114': `Input parameter error / product number of digits excess`,
    'RC3000115': `Input parameter error / product ྡ format invalid`,
    'RC4000001': `Input parameter error / Currency code not specified`,
    'RC4000002': `Subject required error`,
    'RC4000003': `Input parameter error / Currency code digit excess`,
    'RC4000004': `Input parameter error / incorrect currency code format`,
    'RC4000010': `Input parameter error / Purchaser Mr. ྡ not specified`,
    'RC4000101': `Bank code required error`,
    'RC4000102': `Account number digit number over`,
    'RC4000103': `Account number format error`,
    'RC4000104': `Payment history existence check error There is no payment history.`,
    'RC4000105': `Account Information Entry Unauthorized continuing account ID or account information (bank code, branch code, item code, account number) Please specify either.`,
    'RC4000106': `Input parameter error / Buyer's number of digits exceeded`,
    'RC4000107': `Input parameter error / Buyer Mr. format invalid`,
    'RC4000108': `Input parameter error / E-mail address not specified`,
    'RC4000109': `Input parameter error / E-mail address digit number excess`,
    'RC4009999': `Input parameter error / Order number digit excess`,
    'E61214002': `Input parameter error / Template No. not specified`,
    'E61214010': `Input parameter error / Invalid template number format`,
    'E61219002': `Input parameter error / Message language No. not specified`,
    'M01215001': `Input parameter error / Invalid message language No. format`,
    'M01215005': `Input parameter error / Invalid range of valid days`,
    'M01215006': `Input parameter error / Currency code error
  - The specified currency code does not exist.
  - The amount of money used exceeds the maximum amount of money for the specified currency code.
  - A currency code that can not be used by the specified payment method is specified`,
    'M01216012': `Mail link has not been set.`,
    'M01216013': `Input parameter error / Transfer specified date not specified`,
    'M01217012': `Input parameter error / Transfer specified date format incorrect`,
    'M01217013': `Input parameter error / billing number of digits exceeded`,
    'M01218005': `Input parameter error / Billing content format incorrect`,
    'M01218008': `Input parameter error / Incorrect check mode`,
    'M01219004': `Input parameter error / specified account does not exist`,
    'M01220001': `Error in input parameter / account transfer is out of process.`,
    'M01220002': `Input parameter error / Out of charge acceptance period`,
    'M01220005': `System error / Billing acceptance failure`,
    'M01220010': `System error / Billing deadline failure`,
    'M01220013': `System error / Billing result reflection failure`,
    'M01221001': `System error / Inconsistent result`,
    'M01221005': `There is no trade in Paid.`,
    'M01221006': `An error code (call parameter invalid) was returned from Paid.`,
    'M01222001': `An error occurred on the Paid side.`,
    'M01222005': `The request number limit has been exceeded.`,
    'M01222006': `An unexpected status has been returned from Paid.`,
    'M01223001': `The specified trading partner is not available.`,
    'M01223011': `The specified trading partner is over the limit amount.`,
    'M01224001': `An error code (illegal parameter) was returned from Paid.`,
    'M01224005': `An error code (insufficient parameter content) was returned from Paid.`,
    'M01224006': `An error code (Paid customer ID registered) has been returned from Paid.`,
    'M01225002': `The specified Paid customer ID does not exist.`,
    'M01259010': `An error code (others) has been returned from Paid.`,
    'M01290001': `The specified trading partner has been registered.`,
    'M01290008': `Input parameter error / Customer ID not specified`,
    'M01291001': `Input parameter error / Business partner ID digit excess`,
    'M01291005': `Input parameter error / Business partner ID format incorrect`,
    'M01291008': `Input parameter error / company ྡ not specified`,
    'M01291010': `Input parameter error / company number of digits excess`,
    'M01292001': `Input parameter error / Company ྡ Kana not specified`,
    'M01292005': `Input parameter error / Company ྡ number of digits excess`,
    'M01292008': `Input parameter error / representative surname not specified`,
    'M01293001': `Input parameter error / representative surname digit number excess`,
    'M01293005': `Input parameter error / representative ྡ not specified`,
    'M01293008': `Input parameter error / representative 者 number of digits excess`,
    'M01294001': `Input parameter error / Representative surname Kana not specified`,
    'M01294005': `Input parameter error / representative surname surpasses kana digit number excess`,
    'M01294008': `Input parameter error / Representative company ྡ Kana not specified`,
    'M01295001': `Input parameter error / Representative company ྡ Kana digit number excess`,
    'M01295005': `Input parameter error / Zip code not specified`,
    'M01296001': `Input parameter error / Incorrect postal code format`,
    'M01296008': `Input parameter error / Unspecified state`,
    'M01297001': `Input parameter error / State digit excess`,
    'M01297008': `Input parameter error / city not specified`,
    'M01298011': `Input parameter error / municipality number of digits excess`,
    'M01299010': `Input parameter error / Street address / address not specified`,
    'E61300002': `Input parameter error / Town square · Address digit excess`,
    'M01330001': `Input parameter error / Building · apartment ྡ digit number excess`,
    'M01330006': `Input parameter error / department ྡ / branch 超過 digit excess`,
    'M01330010': `Input parameter error / department ྡ / branch 超過 digit excess`,
    'M01331005': `Input parameter error / Contact person surname not specified`,
    'M01331006': `Input parameter error / Contact person surname digit number excess`,
    'M01335005': `Input parameter error / person in charge ྡ not specified`,
    'M01332002': `Input parameter error / person in charge ྡ digit number excess`,
    'M01333002': `Input parameter error / Contact person surname Kana not specified`,
    'M01333011': `Input parameter error / Contact person surname Kana digit number excess`,
    'M01334011': `Input parameter error / Contact person surname Kana digit number excess`,
    'AC2000001': `Input parameter error / person in charge 未 Kana not specified`,
    'AC2000002': `Input parameter error / person in charge ྡ Kana digit number excess`,
    'AC2000003': `Input parameter error / No phone number specified`,
    'AC2000004': `Input parameter error / Invalid telephone number format`,
    'PD1000001': `Input parameter error / Incorrect fax number format`,
    'PD1000002': `Input parameter error / Invalid mobile phone number format`,
    'PD1000003': `Input parameter error / E-mail address format invalid`,
    'PD1000004': `Input parameter error / Date of establishment (not yearly)`,
    'PD1000005': `Input parameter error / out of range of establishment date (year)`,
    'PD1000006': `Input parameter error / Other than establishment date (month)`,
    'PD1000007': `Input parameter error / out of range of establishment date (month)`,
    'PD1000009': `Input parameter error / Other than year quotient`,
    'PD1000010': `Input parameter error / out of year quotient range`,
    'PD1000011': `Input parameter error / Other than industry number`,
    'PD1000012': `Input parameter error / industry number out of range`,
    'PD1000013': `Input parameter error / Handling brand / excess of product digits`,
    'PD1000014': `Input parameter error / Other than the number of stores`,
    'M01360001': `Input parameter error / Number of stores out of range`,
    'M01360005': `Input parameter error / URL one digit excess`,
    'M01360008': `Input parameter error / Invalid URL1 format`,
    'M01361001': `Input parameter error / URL 2 digits excess`,
    'M01361005': `Input parameter error / URL2 format invalid`,
    'M01362001': `Input parameter error / URL 3 digits excess`,
    'M01362005': `Input parameter error / URL3 format invalid`,
    'M01363001': `Input parameter error / PR digit number excess`,
    'M01363005': `Input parameter error / Closing date format incorrect`,
    'M01364001': `Input parameter error / Payment method format incorrect`,
    'M01364005': `Input parameter error / representative 者 number of digits excess`,
    'M01365001': `Input parameter error / Representative surname Kana not specified`,
    'M01365005': `Input parameter error / representative surname surpasses kana digit number excess`,
    'M01366001': `Input parameter error / Representative company ྡ Kana not specified`,
    'M01366005': `Input parameter error / Representative company ྡ Kana digit number excess`,
    'M01367001': `Input parameter error / Zip code not specified`,
    'M01367008': `Input parameter error / Incorrect postal code format`,
    'M01368001': `Input parameter error / Unspecified state`,
    'M01368005': `Input parameter error / State digit excess`,
    'M01369001': `Input parameter error / city not specified`,
    'M01369005': `Input parameter error / municipality number of digits excess`,
    'M01370001': `Input parameter error / Street address / address not specified`,
    'M01370005': `Input parameter error / Town square · Address digit excess`,
    'M01371005': `Input parameter error / Building · apartment ྡ digit number excess`,
    'M01372005': `Input parameter error / department ྡ / branch 超過 digit excess`,
    'M01373001': `Input parameter error / Contact person surname not specified`,
    'M01373005': `Input parameter error / Contact person surname digit number excess`,
    'M01374001': `Input parameter error / person in charge ྡ not specified`,
    'M01374005': `Input parameter error / person in charge ྡ digit number excess`,
    'M01375001': `Input parameter error / Contact person surname Kana not specified`,
    'M01375005': `Input parameter error / Contact person surname Kana digit number excess`,
    'M01376001': `Input parameter error / person in charge 未 Kana not specified`,
    'M01376005': `Input parameter error / person in charge ྡ Kana digit number excess`,
    'M01377001': `Input parameter error / No phone number specified`,
    'M01377008': `Input parameter error / Invalid telephone number format`,
    'M01378008': `Input parameter error / Incorrect fax number format`,
    'M01379008': `Input parameter error / Invalid mobile phone number format`,
    'M01380001': `Input parameter error / Representative company ྡ Kana digit number excess`,
    'M01380005': `Input parameter error / Zip code not specified`,
    'M01380008': `Input parameter error / E-mail address format invalid`,
    'M01383006': `Input parameter error / Date of establishment (not yearly)`,
    'M01383011': `Input parameter error / out of range of establishment date (year)`,
    'M01384006': `Input parameter error / Other than establishment date (month)`,
    'M01384011': `Input parameter error / out of range of establishment date (month)`,
    'M01385006': `Input parameter error / Other than year quotient`,
    'M01385011': `Input parameter error / out of year quotient range`,
    'M01386006': `Input parameter error / Other than industry number`,
    'M01386011': `Input parameter error / industry number out of range`,
    'M01387005': `Input parameter error / Handling brand / excess of product digits`,
    'M01388006': `Input parameter error / Other than the number of stores`,
    'M01388011': `Input parameter error / Number of stores out of range`,
    'M01389005': `Input parameter error / URL one digit excess`,
    'M01389008': `Input parameter error / Invalid URL1 format`,
    'M01390005': `Input parameter error / URL 2 digits excess`,
    'M01390008': `Input parameter error / URL2 format invalid`,
    'M01391005': `Input parameter error / URL 3 digits excess`,
    'M01391008': `Input parameter error / URL3 format invalid`,
    'M01392005': `Input parameter error / PR digit number excess`,
    'M01381008': `Input parameter error / Closing date format incorrect`,
    'M01382008': `Input parameter error / Payment method format incorrect`,
    'E01060021': `Captured amount does not match authorized amount`,
    'E01180011': `Wrong Format (for "Expire")`,
    'E01200007': `Wrong SiteID`,
    'E01220010': `The specified "SiteID" has been already used.`,
    'E01220012': `Wrong Length (for "MemberID")`,
    'E01480011': `The number of characters for "HolderName" exceeds the limit.`,
    'E01770002': `Invalid Value is set for transaction type.`,
    'E01780002': `Invalid value is set for card validity check. Please set "0" for this parameter.`,
    'E01790007': `Invalid value is set for check date.`,
    'E01790011': `The number of characters exceeds the limit for check date.`,
    'E01850008': `Wrong format (for "UpdateType")`,
    'E01860008': `Wrong format (for Card Number Masking Flag)`,
    'E01870008': `Wrong format (for TokenType)`,
    'E01880001': `"MemberID" is not specified.`,
    'E01880002': `Neither the specified SiteID nor MemberID does not exist.`,
    'E01880008': `Wrong format (for "MemberID")`,
    'E01890001': `"CardSeq" is not specified.`,
    'E01890002': `The specified "MemberID" does not exist.`,
    'E01890006': `Wrong format (for "CardSeq"). Please use numbers only.`,
    'E01890009': `Card cannot be registered for the specified MemberID. Please note that each MemberID can have up to 5 cards.`,
    'E01999998': `"001" is not specified for "Format Version".`,
    'E61040001': `Raw PAN (=card number) cannot be processed under the current merchant contract.`,
    'EX1000304': `Settlement process failed. Please enter card number again.`,
    '42G070000': `The card limit has been exceeded`
};
